summaryrefslogtreecommitdiffstats
path: root/crypto/cmp/cmp_local.h
diff options
context:
space:
mode:
authorDr. David von Oheimb <David.von.Oheimb@siemens.com>2021-08-06 11:45:13 +0200
committerHugo Landau <hlandau@openssl.org>2022-07-01 07:38:50 +0100
commit74107c4428edbe8d6797ac6a700e0ea2c9e14952 (patch)
tree8b1fc134a2bb1e80571ffdcce9cbb99a68af71f0 /crypto/cmp/cmp_local.h
parentc4ad4e5bf67dae6f7729de5438c9a96a2abd0f92 (diff)
CMP: implement optional hashAlg field of certConf CMPv3 message
Reviewed-by: Tomas Mraz <tomas@openssl.org> Reviewed-by: Paul Dale <pauli@openssl.org> Reviewed-by: Hugo Landau <hlandau@openssl.org> (Merged from https://github.com/openssl/openssl/pull/18294)
Diffstat (limited to 'crypto/cmp/cmp_local.h')
-rw-r--r--crypto/cmp/cmp_local.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/crypto/cmp/cmp_local.h b/crypto/cmp/cmp_local.h
index 07a8c8eab2..255eb58ba6 100644
--- a/crypto/cmp/cmp_local.h
+++ b/crypto/cmp/cmp_local.h
@@ -369,13 +369,15 @@ DECLARE_ASN1_FUNCTIONS(OSSL_CMP_ERRORMSGCONTENT)
* -- as is used to create and verify the certificate signature
* certReqId INTEGER,
* -- to match this confirmation with the corresponding req/rep
* statusInfo PKIStatusInfo OPTIONAL
* }
*/
struct ossl_cmp_certstatus_st {
ASN1_OCTET_STRING *certHash;
ASN1_INTEGER *certReqId;
OSSL_CMP_PKISI *statusInfo;
+ X509_ALGOR *hashAlg; /* 0 */
} /* OSSL_CMP_CERTSTATUS */;
DECLARE_ASN1_FUNCTIONS(OSSL_CMP_CERTSTATUS)
typedef STACK_OF(OSSL_CMP_CERTSTATUS) OSSL_CMP_CERTCONFIRMCONTENT;
@@ -369,13 +369,15 @@ DECLARE_ASN1_FUNCTIONS(OSSL_CMP_ERRORMSGCONTENT)
* certReqId INTEGER,
* -- to match this confirmation with the corresponding req/rep
- * statusInfo PKIStatusInfo OPTIONAL
+ * statusInfo PKIStatusInfo OPTIONAL,
+ * hashAlg [0] AlgorithmIdentifier OPTIONAL
* }
*/